package com.example.jiangningquatz.quartz;


import cn.hutool.core.collection.ListUtil;
import com.dingtalk.api.DefaultDingTalkClient;
import com.dingtalk.api.DingTalkClient;
import com.dingtalk.api.request.OapiAttendanceListRequest;
import com.dingtalk.api.request.OapiGettokenRequest;
import com.dingtalk.api.response.OapiAttendanceListResponse;
import com.dingtalk.api.response.OapiAttendanceListResponse.Recordresult;
import com.dingtalk.api.response.OapiGettokenResponse;
import com.example.jiangningquatz.request.DataRequest;
import com.example.jiangningquatz.request.DateRequest;
import com.taobao.api.ApiException;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.ArrayList;
import java.util.List;

/**
 * 打卡定时任务
 *
 * @author wu
 * @since 2023/8/12 19:18
 */
//@Configuration
//@EnableScheduling

@RestController
@RequestMapping("/jn/daka")
public class RecordQuartz {


    @Value("${dingtalk.accessKey}")
    private String accessKey;

    @Value("${dingtalk.accessSecret}")
    private String accessSecret;

    /**
     * 钉钉的token认证
     */
    public String getAccessToken() {
        //
        String token = null;
        try {
            DingTalkClient client = new DefaultDingTalkClient("https://oapi.dingtalk.com/gettoken");
            OapiGettokenRequest request = new OapiGettokenRequest();
            request.setAppkey(accessKey);
            request.setAppsecret(accessSecret);
            request.setHttpMethod("GET");
            OapiGettokenResponse response = client.execute(request);
            token = response.getAccessToken();
        } catch (Exception e) {
            e.printStackTrace();
        }
        return token;
    }


    /**
     * @description -> 获取用户考勤数据
     */
    @PostMapping("/list")
    public List<Recordresult> getUserAttendanceDetails(@RequestBody DataRequest request) throws ApiException {
        List<List<String>> partition = ListUtil.partition(request.getUserIdList(), 25);
        List<Recordresult> newList = new ArrayList<>();
        for (List<String> sublist : partition) {
            DingTalkClient client = new DefaultDingTalkClient("https://oapi.dingtalk.com/attendance/list");
            OapiAttendanceListRequest req = new OapiAttendanceListRequest();
            req.setUserIdList(sublist);
            req.setOffset(0L);
            req.setLimit(50L);
            // 获取当前日期并格式化为yyyymmddHHmmss
            LocalDateTime now = LocalDateTime.now();
            LocalDateTime WorkDateToTime = now.withHour(23).withMinute(59).withSecond(59).minusDays(1);;
            DateTimeFormatter WorkDateTomatter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
            String WorkDateTo = WorkDateToTime.format(WorkDateTomatter);
            // 获取当前日减一天
            LocalDateTime WorkDateFromTime = now.withHour(0).withMinute(0).withSecond(0).minusDays(1);
            DateTimeFormatter WorkDateFromTimematter = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
            String WorkDateFrom =  WorkDateFromTime.format(WorkDateFromTimematter);
            req.setWorkDateFrom(WorkDateFrom);
            req.setWorkDateTo(WorkDateTo);
            req.setIsI18n(false);
            OapiAttendanceListResponse rsp = client.execute(req, getAccessToken());
            List<Recordresult> list1 = rsp.getRecordresult();
            newList.addAll(list1);
        }
        return newList;
    }

    //半年
    @PostMapping("/midyearlist")
    public List<Recordresult> getUserDetails(@RequestBody DateRequest request) throws ApiException {
        List<List<String>> partition = ListUtil.partition(request.getUserIdList(), 25);
        List<Recordresult> newList = new ArrayList<>();
        for (List<String> sublist : partition) {
            DingTalkClient client = new DefaultDingTalkClient("https://oapi.dingtalk.com/attendance/list");
            OapiAttendanceListRequest req = new OapiAttendanceListRequest();
            req.setUserIdList(sublist);
            req.setWorkDateFrom(request.getBegainTime());
            req.setWorkDateTo(request.getEndTime());
            req.setOffset(0L);
            req.setLimit(50L);
            req.setIsI18n(false);
            OapiAttendanceListResponse rsp = client.execute(req, getAccessToken());
            List<Recordresult> list1 = rsp.getRecordresult();
            newList.addAll(list1);
        }

        return newList;
    }
}
